<template>
  <el-breadcrumb class="app-breadcrumb" separator="/">
    <transition-group name="breadcrumb">
      <el-breadcrumb-item v-for="(item,index) in levelList" :key="item.path+index">
        <span v-if="item.redirect==='noRedirect'||index==levelList.length-1" class="no-redirect">{{ item.meta.title }}</span>
        <a v-else @click.prevent="handleLink(item)">{{ item.meta.title }}</a>
      </el-breadcrumb-item>
    </transition-group>
  </el-breadcrumb>
</template>

<script>
import pathToRegexp from 'path-to-regexp'

export default {
  data() {
    return {
      levelList: null
    }
  },
  watch: {
    $route() {
      this.getBreadcrumb()
    }
  },
  created() {
    this.getBreadcrumb()
  },
  methods: {
    getBreadcrumb() {
      // only show routes with meta.title
      let matched = this.$route.matched.filter(item => item.meta && item.meta.title)
      // 利用reduce方法遍历数组,reduce第一个参数是遍历需要执行的函数，第二个参数是item的初始值
      let obj = {};
      matched = matched.reduce((prev, item) => {
        if (!obj[item.meta.title]) {
          prev.push(item)
          obj[item.meta.title] = true
        }
        return prev
      }, [])
      const first = matched[0]
      if (!this.isDashboard(first)) {
        matched = [{ path: '/', meta: { title: '权益品后台管理' } }].concat(matched)
      }
      this.levelList = matched.filter(item => {
        return item.meta && item.meta.title && item.meta.breadcrumb !== false
      })
      let path = '';
      if(this.$router.options.routes[0]&&this.$router.options.routes[0].children[0]){
          path = this.$router.options.routes[0].children[0].path;
      }else{
        path = this.$router.options.routes[0].path;
      }
      // this.levelList[1].redirect= 'noRedirect'
      // if  (this.levelList[2] && this.levelList.length >3 && this.levelList[2].path!='/finance/qyj-reconciliation' ){
      //         this.levelList[2].redirect= 'noRedirect'
      // }
      this.levelList[0].path = path;
    },
    isDashboard(route) {
      const name = route && route.name
      if (!name) {
        return false
      }
      return name.trim().toLocaleLowerCase() === 'Dashboard'.toLocaleLowerCase()
    },
    pathCompile(path) {
      // To solve this problem https://github.com/PanJiaChen/vue-element-admin/issues/561
      const { params } = this.$route
      var toPath = pathToRegexp.compile(path)
      return toPath(params)
    },
    handleLink(item) {
      console.log(item)
      const { redirect, path } = item
      if (redirect) {
        this.$router.push(redirect)
        return
      }
      if(this.pathCompile(path)=='/order/dashboard-detail'){
        this.$router.push({path:this.pathCompile(path),query:{
          orderId:this.$route.query.orderId
        }})
      }else{
 
        if(path=='/finance/settleDetail'){
                         this.$router.push({path:this.pathCompile(path),query:{
                           id:this.$route.query.id
               }})
        }else{
              this.$router.push(this.pathCompile(path))
        }
      }
    }
  }
}
</script>

<style lang="scss" scoped>
.app-breadcrumb.el-breadcrumb {
  display: inline-block;
  font-size: 14px;
  line-height: 50px;
  margin-left: 8px;

  .no-redirect {
    color: #97a8be;
    cursor: text;
  }
}
</style>
